@@ -16,18 +16,31 @@
 #include "MAVEfast_emxutil.h"
 
 /* Function Definitions */
-void rdivide(const emxArray_real_T *x, const emxArray_real_T *y, emxArray_real_T
-             *z)
+void b_rdivide(const emxArray_real_T *x, const emxArray_real_T *y,
+               emxArray_real_T *z)
 {
-  int i5;
+  int i12;
   int loop_ub;
-  i5 = z->size[0] * z->size[1];
+  i12 = z->size[0] * z->size[1];
   z->size[0] = x->size[0];
   z->size[1] = x->size[1];
-  emxEnsureCapacity((emxArray__common *)z, i5, (int)sizeof(double));
+  emxEnsureCapacity((emxArray__common *)z, i12, sizeof(double));
   loop_ub = x->size[0] * x->size[1];
-  for (i5 = 0; i5 < loop_ub; i5++) {
-    z->data[i5] = x->data[i5] / y->data[i5];
+  for (i12 = 0; i12 < loop_ub; i12++) {
+    z->data[i12] = x->data[i12] / y->data[i12];
+  }
+}
+
+void rdivide(const emxArray_real_T *y, emxArray_real_T *z)
+{
+  int i6;
+  int loop_ub;
+  i6 = z->size[0];
+  z->size[0] = y->size[0];
+  emxEnsureCapacity((emxArray__common *)z, i6, sizeof(double));
+  loop_ub = y->size[0];
+  for (i6 = 0; i6 < loop_ub; i6++) {
+    z->data[i6] = 1.0 / y->data[i6];
   }
 }
 
